within ;
model Hochhaus4 "Parallelschaltung, Stockwerke 1-5"

  replaceable package Medium =
      Modelica.Media.Water.ConstantPropertyLiquidWater;

  Modelica.Fluid.Sources.FixedBoundary SOURCE(nPorts=1,
    redeclare package Medium = Medium,
    use_p=true,
    use_T=true,
    T=system.T_ambient,
    p=106000)                                           annotation (Placement(
        transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={340,-304})));

  Modelica.Fluid.Pipes.StaticPipe R1(
    redeclare package Medium = Medium,
    isCircular=true,
    height_ab=0,
    length=35e-2,
    roughness=20e-6,
    diameter=45.2e-3)
                    annotation (Placement(transformation(
        extent={{-4,-6},{4,6}},
        rotation=180,
        origin={314,-304})));

  Modelica.Fluid.Pipes.StaticPipe R4(
    redeclare package Medium = Medium,
    isCircular=true,
    roughness=7e-6,
    height_ab=-0.115,
    length=0.115,
    diameter=45.2e-3)
                  annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=270,
        origin={218,-315})));

  Modelica.Fluid.Pipes.StaticPipe R5(
    redeclare package Medium = Medium,
    isCircular=true,
    height_ab=0,
    roughness=7e-6,
    diameter=45.2e-3,
    length=0.3)     annotation (Placement(transformation(
        extent={{-7,-6},{7,6}},
        rotation=180,
        origin={197,-326})));

  Custom_Pump_V2.BaseClasses_Custom.Pump_vs GF80_2(
    redeclare package Medium = Medium,
    m_flow_start=0.24,
    redeclare function flowCharacteristic =
        Custom_Pump.BaseClasses_Custom.PumpCharacteristics.quadraticFlow (c={-0.065158,
            0.34196,8.1602}),
    redeclare function powerCharacteristic =
        Custom_Pump.BaseClasses_Custom.PumpCharacteristics.cubicPower (c={-0.14637,
            1.1881,23.0824,53.0304,6.0431}),
    rpm_rel=0.93969,
    use_N_in=true,
    V=0.1,
    use_HeatTransfer=true,
    redeclare model HeatTransfer =
        Modelica.Fluid.Vessels.BaseClasses.HeatTransfer.IdealHeatTransfer)
                   annotation (Placement(transformation(
        extent={{-12,-12},{12,12}},
        rotation=90,
        origin={74,-172})));

  Modelica.Fluid.Pipes.StaticPipe R14(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=0.3,
    height_ab=0.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={94,78})));

Real P_ges(unit="W") "Gesamtleistung";
Real eta_ges "Gesamtwirkungsgrad";
Real head_ges(unit="m") "Gesamtfoerderhoehe";

  inner Modelica.Fluid.System system(
    g=9.81,
    p_ambient=99000,
    T_ambient=293.15)
    annotation (Placement(transformation(extent={{354,-354},{374,-334}})));

  Modelica.Fluid.Pipes.StaticPipe R16(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=2.3,
    height_ab=2.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-74,76})));

  Modelica.Fluid.Pipes.StaticPipe R17(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=4.3,
    height_ab=4.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-260,78})));

  Custom_Sensors.VolumeFlowRate_nonSI Q_ges(redeclare package Medium =
        Medium) annotation (Placement(
        transformation(
        extent={{-15,14},{15,-14}},
        rotation=180,
        origin={171,-326})));
  Modelica.Fluid.Pipes.StaticPipe R3(
    redeclare package Medium = Medium,
    isCircular=true,
    height_ab=0,
    length=0.5,
    roughness=7e-6,
    diameter=45.2e-3)
                    annotation (Placement(transformation(
        extent={{-8,-6},{8,6}},
        rotation=180,
        origin={242,-304})));

  Modelica.Fluid.Pipes.StaticPipe R2(
    redeclare package Medium = Medium,
    isCircular=true,
    height_ab=0,
    length=12.5e-2,
    roughness=7e-6,
    diameter=45.2e-3)
                    annotation (Placement(transformation(
        extent={{-4,-6},{4,6}},
        rotation=180,
        origin={282,-304})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T1_1(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.4) annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=90,
        origin={150,-321})));

  Modelica.Fluid.Fittings.AbruptAdaptor V2(
    redeclare package Medium = Medium,
    diameter_a=20e-3,
    diameter_b=25e-3) annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=90,
        origin={74,-210})));

  Modelica.Fluid.Fittings.AbruptAdaptor V4(
    redeclare package Medium = Medium,
    diameter_a=25e-3,
    diameter_b=20e-3) annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=90,
        origin={74,-148})));

  Modelica.Fluid.Fittings.AbruptAdaptor V1(
    redeclare package Medium = Medium,
    diameter_a=20e-3,
    diameter_b=25e-3) annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=90,
        origin={150,-210})));

  Modelica.Fluid.Fittings.AbruptAdaptor V3(
    redeclare package Medium = Medium,
    diameter_a=25e-3,
    diameter_b=20e-3) annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=90,
        origin={150,-148})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T5S(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.9) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-74,14})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T4S(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.9) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={94,14})));

  Modelica.Fluid.Fittings.Bends.CurvedBend B2(redeclare package Medium =
        Medium, geometry(
      R_0=62e-3,
      d_hyd=45.2e-3,
      delta=1.5707963267949,
      K=7e-9)) annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=180,
        origin={265,-304})));
  Modelica.Fluid.Fittings.Bends.CurvedBend B3(redeclare package Medium =
        Medium, geometry(
      R_0=62e-3,
      d_hyd=45.2e-3,
      delta=1.5707963267949,
      K=7e-9)) annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=180,
        origin={225,-304})));
  Modelica.Fluid.Fittings.Bends.CurvedBend B4(redeclare package Medium =
        Medium, geometry(
      R_0=62e-3,
      d_hyd=45.2e-3,
      delta=1.5707963267949,
      K=7e-9)) annotation (Placement(transformation(
        extent={{-5,6},{5,-6}},
        rotation=180,
        origin={213,-326})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H1(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.3) annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=90,
        origin={150,-297})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice E4(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.8) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-260,48})));

  Modelica.Fluid.Pipes.StaticPipe D_H2(
    redeclare package Medium = Medium,
    isCircular=true,
    length=0.18,
    height_ab=0.18,
    roughness=0,
    diameter=25e-3)
                 annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=90,
        origin={74,-194})));

  Modelica.Fluid.Pipes.StaticPipe D_H1(
    redeclare package Medium = Medium,
    isCircular=true,
    length=0.18,
    height_ab=0.18,
    roughness=0,
    diameter=25e-3) annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=90,
        origin={150,-194})));

  Custom_Fittings.CurvedBend_Cutom B1(
               redeclare package Medium =
        Medium, geometry(
      R_0=62e-3,
      d_hyd=45.2e-3,
      delta=1.5707963267949,
      K=7e-9))                                            annotation (Placement(
        transformation(
        extent={{-5,-6},{5,6}},
        rotation=180,
        origin={299,-304})));

  Custom_Pump_V2.BaseClasses_Custom.Pump_vs
                                         GF80_1(
    redeclare package Medium = Medium,
    m_flow_start=0.24,
    redeclare function flowCharacteristic =
        Custom_Pump.BaseClasses_Custom.PumpCharacteristics.quadraticFlow (c={-0.065158,
            0.34196,8.1602}),
    redeclare function powerCharacteristic =
        Custom_Pump.BaseClasses_Custom.PumpCharacteristics.cubicPower (c={-0.14637,
            1.1881,23.0824,53.0304,6.0431}),
    rpm_rel=0.93969,
    use_N_in=true,
    V=0.1,
    use_HeatTransfer=true,
    redeclare model HeatTransfer =
        Modelica.Fluid.Vessels.BaseClasses.HeatTransfer.IdealHeatTransfer)
                     annotation (Placement(transformation(
        extent={{-12,-12},{12,12}},
        rotation=90,
        origin={150,-172})));

  Modelica.Fluid.Pipes.StaticPipe R7(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=0.34,
    height_ab=0.34) annotation (Placement(transformation(
        extent={{-7,-8},{7,8}},
        rotation=90,
        origin={150,-273})));

  Modelica.Fluid.Pipes.StaticPipe R8(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=0.34,
    height_ab=0.34) annotation (Placement(transformation(
        extent={{-7,-8},{7,8}},
        rotation=90,
        origin={74,-273})));

  Modelica.Fluid.Pipes.StaticPipe D_A2(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=1e-5,
    length=0.135,
    height_ab=0.135) annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=90,
        origin={74,-228})));

  Modelica.Fluid.Pipes.StaticPipe D_A1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=1e-5,
    length=0.135,
    height_ab=0.135) annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=90,
        origin={150,-228})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice U2(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=90,
        origin={74,-245})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice U1(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=90,
        origin={150,-243})));

  Modelica.Fluid.Pipes.StaticPipe D_B2(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=1e-5,
    length=0.2,
    height_ab=0.2)  annotation (Placement(transformation(
        extent={{-5,-8},{5,8}},
        rotation=90,
        origin={74,-133})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H4(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=90,
        origin={74,-118})));

  Modelica.Fluid.Pipes.StaticPipe D_B1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=1e-5,
    length=0.2,
    height_ab=0.2)  annotation (Placement(transformation(
        extent={{-5,-8},{5,8}},
        rotation=90,
        origin={150,-133})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H3(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=90,
        origin={150,-118})));

  Modelica.Fluid.Pipes.StaticPipe R10(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=0.50,
    height_ab=0.50) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={74,-96})));

  Modelica.Fluid.Pipes.StaticPipe R9(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=0.50,
    height_ab=0.50) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={150,-96})));

  Modelica.Fluid.Sources.FixedBoundary SINK(
    redeclare package Medium = Medium,
    use_p=true,
    use_T=true,
    T=system.T_ambient,
    p=99000,
    nPorts=5)
             annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={388,326})));

  Modelica.Fluid.Pipes.StaticPipe H5_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.195,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={209,140})));

  Custom_Sensors.VolumeFlowRate_nonSI Q_floor1(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{218,150},{238,130}})));

  Custom_Sensors.VolumeFlowRate_nonSI Q_floor3(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
        rotation=0,
        origin={106,402})));
  Modelica.Fluid.Valves.ValveIncompressible Valve_floor3(
    redeclare package Medium = Medium,
    filteredOpening=false,
    CvData=Modelica.Fluid.Types.CvTypes.Kv,
    m_flow_nominal=1,
    Kv=29.5,
    dp_nominal=100000,
    checkValve=true,
    redeclare function valveCharacteristic =
        Modelica.Fluid.Valves.BaseClasses.ValveCharacteristics.equalPercentage)
    annotation (Placement(transformation(extent={{156,392},{176,412}})));

  Custom_Sensors.VolumeFlowRate_nonSI Q_floor5(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
        rotation=0,
        origin={108,650})));
  Modelica.Fluid.Valves.ValveIncompressible Valve_floor5(
    redeclare package Medium = Medium,
    filteredOpening=false,
    CvData=Modelica.Fluid.Types.CvTypes.Kv,
    m_flow_nominal=1,
    Kv=29.5,
    dp_nominal=100000,
    checkValve=true,
    redeclare function valveCharacteristic =
        Modelica.Fluid.Valves.BaseClasses.ValveCharacteristics.equalPercentage)
    annotation (Placement(transformation(extent={{156,640},{176,660}})));

  Modelica.Fluid.Valves.ValveIncompressible Valve_floor1(
    redeclare package Medium = Medium,
    CvData=Modelica.Fluid.Types.CvTypes.Kv,
    filteredOpening=false,
    m_flow_nominal=1,
    Kv=29.5,
    dp_nominal=100000,
    checkValve=true,
    redeclare function valveCharacteristic =
        Modelica.Fluid.Valves.BaseClasses.ValveCharacteristics.equalPercentage)
    annotation (Placement(transformation(extent={{260,130},{280,150}})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice K1(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={148,140})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice E5(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.8) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-260,640})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice E3(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.8) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-72,392})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice E2(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.8) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={94,130})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H5(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={188,140})));

  Modelica.Fluid.Pipes.StaticPipe s1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=0.115) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={113,140})));

  Modelica.Fluid.Pipes.StaticPipe K1_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.1,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={129,140})));

  Modelica.Fluid.Pipes.StaticPipe QS1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.155,
    roughness=1e-5) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={169,140})));

  Modelica.Fluid.Pipes.StaticPipe K2_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=0.5)     annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={319,140})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice K2(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={296,140})));

  Modelica.Fluid.Pipes.StaticPipe H6_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.195,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={85,402})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice K3(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={24,402})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H6(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={64,402})));

  Modelica.Fluid.Pipes.StaticPipe s2(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=0.915) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={-13,402})));

  Modelica.Fluid.Pipes.StaticPipe K3_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.1,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={3,402})));

  Modelica.Fluid.Pipes.StaticPipe QS2(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.155,
    roughness=1e-5) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={45,402})));

  Modelica.Fluid.Pipes.StaticPipe H7_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.195,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={87,650})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice K5(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={26,650})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H7(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={66,650})));

  Modelica.Fluid.Pipes.StaticPipe s3(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=1.715) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={-11,650})));

  Modelica.Fluid.Pipes.StaticPipe K5_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.1,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={5,650})));

  Modelica.Fluid.Pipes.StaticPipe QS3(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.155,
    roughness=1e-5) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={47,650})));

  Modelica.Fluid.Pipes.StaticPipe K4_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=0.5) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={237,402})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice K4(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={216,402})));

  Modelica.Fluid.Pipes.StaticPipe K6_R(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=0.5) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={237,650})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice K6(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={216,650})));

  Modelica.Fluid.Pipes.StaticPipe R15(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=80e-2) annotation (Placement(transformation(
        extent={{11,-8},{-11,8}},
        rotation=0,
        origin={45,-14})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T4D(
    redeclare package Medium = Medium,
    diameter=20e-3,
    zeta=0.3) annotation (Placement(transformation(extent={{82,-22},{66,-6}})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T3_1(
    diameter=20e-3,
    redeclare package Medium = Medium,
    zeta=0.5) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=90,
        origin={150,-74})));

  Modelica.Fluid.Pipes.StaticPipe R6(
    length=0.2,
    diameter=45.2e-3,
    redeclare package Medium = Medium,
    roughness=7e-6)
    annotation (Placement(transformation(extent={{114,-332},{94,-320}})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T1_2(
    redeclare package Medium = Medium,
    diameter=45.2e-3,
    zeta=0.2)
    annotation (Placement(transformation(extent={{134,-332},{122,-320}})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T2(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.4) annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=90,
        origin={74,-321})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H2(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.3) annotation (Placement(transformation(
        extent={{-5,-6},{5,6}},
        rotation=90,
        origin={74,-295})));

  Custom_Pump_V2.BaseClasses_Custom.Pump_vs YONOS(
    redeclare package Medium = Medium,
    use_N_in=true,
    redeclare function flowCharacteristic =
        Custom_Pump_V2.BaseClasses_Custom.PumpCharacteristics.quadraticFlow (c=
            {-0.31462,0.36629,5.0907}),
    redeclare function powerCharacteristic =
        Custom_Pump_V2.BaseClasses_Custom.PumpCharacteristics.cubicPower (c={-0.32719,
            0.36765,16.4571,16.2571,3.5722}),
    V=0.1,
    use_HeatTransfer=true,
    redeclare model HeatTransfer =
        Modelica.Fluid.Vessels.BaseClasses.HeatTransfer.IdealHeatTransfer)
    annotation (Placement(transformation(extent={{-166,-24},{-186,-4}})));

  Modelica.Fluid.Pipes.StaticPipe R11(
    redeclare package Medium = Medium,
    length=0.2,
    diameter=20e-3,
    roughness=7e-6)
    annotation (Placement(transformation(extent={{96,-86},{116,-68}})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice HB1(
    zeta=0.3,
    redeclare package Medium = Medium,
    diameter=20e-3)
    annotation (Placement(transformation(extent={{74,-86},{90,-70}})));

  Modelica.Fluid.Pipes.StaticPipe R12(
    redeclare package Medium = Medium,
    diameter=20e-3,
    roughness=7e-6,
    length=0.19,
    height_ab=0.19) annotation (Placement(transformation(
        extent={{-7,-8},{7,8}},
        rotation=90,
        origin={150,-51})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice HB2(
    zeta=0.3,
    redeclare package Medium = Medium,
    diameter=20e-3) annotation (Placement(transformation(
        extent={{-8,-8},{8,8}},
        rotation=90,
        origin={150,-32})));

  Modelica.Fluid.Pipes.StaticPipe R13(
    redeclare package Medium = Medium,
    length=0.1,
    diameter=20e-3,
    roughness=7e-6)
    annotation (Placement(transformation(extent={{134,-22},{124,-6}})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T5D(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=0.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=180,
        origin={-92,-14})));

  Modelica.Fluid.Pipes.StaticPipe D_H3(
    redeclare package Medium = Medium,
    isCircular=true,
    length=0.18,
    roughness=0,
    diameter=25e-3,
    height_ab=0) annotation (Placement(transformation(
        extent={{-6,-10},{6,10}},
        rotation=180,
        origin={-158,-14})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice U3(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-7,8},{7,-8}},
        rotation=180,
        origin={-115,-14})));

  Modelica.Fluid.Pipes.StaticPipe D_A3(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=1e-5,
    length=0.135,
    height_ab=0) annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=180,
        origin={-130,-14})));

  Modelica.Fluid.Fittings.AbruptAdaptor V5(
    redeclare package Medium = Medium,
    diameter_a=20e-3,
    diameter_b=25e-3) annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=180,
        origin={-144,-14})));

  Modelica.Fluid.Fittings.AbruptAdaptor V6(
    redeclare package Medium = Medium,
    diameter_a=25e-3,
    diameter_b=20e-3) annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=180,
        origin={-220,-14})));

  Modelica.Fluid.Pipes.StaticPipe D_B3(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=1e-5,
    height_ab=0,
    length=0.485)   annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=180,
        origin={-254,-14})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice U4(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=180,
        origin={-238,-14})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice C1(
    redeclare package Medium = Medium,
    diameter=20e-3,
    zeta=1) annotation (Placement(transformation(extent={{332,130},{352,150}})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice C2(
    diameter=20e-3,
    zeta=1,
    redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{248,392},{268,412}})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice C3(
    redeclare package Medium = Medium,
    diameter=20e-3,
    zeta=1) annotation (Placement(transformation(extent={{248,640},{268,660}})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice T3_2(
    redeclare package Medium = Medium,
    diameter=20e-3,
    zeta=0.75)
    annotation (Placement(transformation(extent={{120,-86},{140,-66}})));

  Modelica.Blocks.Interfaces.RealInput u_v_5
    annotation (Placement(transformation(extent={{-318,652},{-278,692}})));
  Modelica.Blocks.Interfaces.RealInput u_v_3
    annotation (Placement(transformation(extent={{-320,400},{-280,440}})));
  Modelica.Blocks.Interfaces.RealInput u_v_1
    annotation (Placement(transformation(extent={{-322,150},{-282,190}})));
  Modelica.Blocks.Interfaces.RealInput u_p_2
    annotation (Placement(transformation(extent={{-320,-14},{-280,26}})));
  Modelica.Blocks.Interfaces.RealInput u_p_1
    annotation (Placement(transformation(extent={{-320,-186},{-280,-146}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_5_v
    annotation (Placement(transformation(extent={{400,610},{428,638}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_3_v
    annotation (Placement(transformation(extent={{400,364},{428,392}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_1_v
    annotation (Placement(transformation(extent={{400,92},{428,120}})));
  Modelica.Blocks.Interfaces.RealOutput y_p_2_p
    annotation (Placement(transformation(extent={{400,-40},{428,-12}})));
  Modelica.Blocks.Interfaces.RealOutput y_p_1_p
    annotation (Placement(transformation(extent={{402,-176},{430,-148}})));
  Modelica.Fluid.Sensors.Pressure pressure(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{168,-160},{188,-140}})));
  Modelica.Fluid.Sensors.Pressure pressure1(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{168,-184},{188,-164}})));
  Modelica.Fluid.Sensors.Pressure pressure2(redeclare package Medium =
        Medium) annotation (Placement(
        transformation(
        extent={{-7,-7},{7,7}},
        rotation=270,
        origin={-179,-33})));
  Modelica.Blocks.Math.Add add(k1=1, k2=-1)
    annotation (Placement(transformation(extent={{204,-172},{224,-152}})));
  Modelica.Fluid.Sensors.Pressure pressure3(redeclare package Medium =
        Medium) annotation (Placement(
        transformation(
        extent={{-7,-7},{7,7}},
        rotation=270,
        origin={-159,-33})));
  Modelica.Blocks.Math.Add add1(k1=-1) annotation (Placement(transformation(
        extent={{-6,-6},{6,6}},
        rotation=270,
        origin={-168,-54})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice H8(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-4,
    zeta=1000)
              annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=180,
        origin={-70,-74})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H9(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-4,
    zeta=1000)
              annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=180,
        origin={112,-130})));

  Modelica.Fluid.Fittings.SimpleGenericOrifice H10(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-4,
    zeta=1000)
              annotation (Placement(transformation(
        extent={{-6,-8},{6,8}},
        rotation=0,
        origin={-162,-86})));

  Modelica.Fluid.Sources.FixedBoundary SINK1(
    redeclare package Medium = Medium,
    use_p=true,
    use_T=true,
    T=system.T_ambient,
    p=99000,
    nPorts=3)
             annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={-112,-124})));

  Modelica.Blocks.Interfaces.RealOutput y_p_1_v
    annotation (Placement(transformation(extent={{400,-202},{428,-174}})));
  Modelica.Blocks.Interfaces.RealOutput y_p_2_v
    annotation (Placement(transformation(extent={{400,-16},{428,12}})));
  Modelica.Fluid.Sensors.Pressure pressure4(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{276,52},{296,72}})));
  Modelica.Fluid.Sensors.Pressure pressure5(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{276,98},{296,78}})));
  Modelica.Blocks.Math.Add add2(k1=1, k2=-1)
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
        rotation=0,
        origin={334,74})));
  Modelica.Blocks.Interfaces.RealOutput y_v_1_p
    annotation (Placement(transformation(extent={{400,60},{428,88}})));
  Modelica.Fluid.Sensors.Pressure pressure6(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{188,620},{208,600}})));
  Modelica.Fluid.Sensors.Pressure pressure7(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{188,572},{208,592}})));
  Modelica.Blocks.Math.Add add3(k1=1, k2=-1)
    annotation (Placement(transformation(extent={{224,584},{244,604}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_5_p
    annotation (Placement(transformation(extent={{400,580},{428,608}})));
  Modelica.Fluid.Sensors.Pressure pressure8(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{184,376},{204,356}})));
  Modelica.Fluid.Sensors.Pressure pressure9(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{184,332},{204,352}})));
  Modelica.Blocks.Math.Add add4(k1=1, k2=-1)
    annotation (Placement(transformation(extent={{220,344},{240,364}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_3_p
    annotation (Placement(transformation(extent={{400,340},{428,368}})));
  Custom_Sensors.VolumeFlowRate_nonSI Q_floor2(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
        rotation=180,
        origin={-200,-14})));
  Modelica.Fluid.Pipes.StaticPipe R18(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=80e-2) annotation (Placement(transformation(
        extent={{11,-8},{-11,8}},
        rotation=0,
        origin={-43,-14})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice T4D1(
    redeclare package Medium = Medium,
    diameter=20e-3,
    zeta=0.3) annotation (Placement(transformation(extent={{-6,-22},{-22,-6}})));
  Modelica.Fluid.Pipes.StaticPipe R19(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=1.3,
    height_ab=1.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={18,76})));
  Modelica.Fluid.Pipes.StaticPipe H5_R1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.195,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={209,276})));
  Custom_Sensors.VolumeFlowRate_nonSI Q_floor4(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{218,286},{238,266}})));
  Modelica.Fluid.Valves.ValveIncompressible Valve_floor2(
    redeclare package Medium = Medium,
    CvData=Modelica.Fluid.Types.CvTypes.Kv,
    filteredOpening=false,
    m_flow_nominal=1,
    Kv=29.5,
    dp_nominal=100000,
    checkValve=true,
    redeclare function valveCharacteristic =
        Modelica.Fluid.Valves.BaseClasses.ValveCharacteristics.equalPercentage)
    annotation (Placement(transformation(extent={{260,266},{280,286}})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice K7(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={148,276})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice E1(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.8) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={18,266})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice H11(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={188,276})));
  Modelica.Fluid.Pipes.StaticPipe s4(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=0.115) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={113,276})));
  Modelica.Fluid.Pipes.StaticPipe K1_R1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.1,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={129,276})));
  Modelica.Fluid.Pipes.StaticPipe QS4(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.155,
    roughness=1e-5) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={169,276})));
  Modelica.Fluid.Pipes.StaticPipe K2_R1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=0.5)     annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={319,276})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice K8(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={296,276})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice C4(
    redeclare package Medium = Medium,
    diameter=20e-3,
    zeta=1) annotation (Placement(transformation(extent={{332,266},{352,286}})));
  Modelica.Fluid.Sensors.Pressure pressure10(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{282,188},{302,208}})));
  Modelica.Fluid.Sensors.Pressure pressure11(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{282,238},{302,218}})));
  Modelica.Blocks.Math.Add add5(k1=1, k2=-1)
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
        rotation=0,
        origin={338,214})));
  Modelica.Blocks.Interfaces.RealInput u_v_2
    annotation (Placement(transformation(extent={{-322,286},{-282,326}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_2_v
    annotation (Placement(transformation(extent={{400,236},{428,264}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_2_p
    annotation (Placement(transformation(extent={{400,200},{428,228}})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice T4S1(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.9) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={18,12})));
  Custom_Sensors.VolumeFlowRate_nonSI Q_floor6(redeclare package Medium =
        Medium)
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
        rotation=0,
        origin={104,524})));
  Modelica.Fluid.Valves.ValveIncompressible Valve_floor4(
    redeclare package Medium = Medium,
    filteredOpening=false,
    CvData=Modelica.Fluid.Types.CvTypes.Kv,
    m_flow_nominal=1,
    Kv=29.5,
    dp_nominal=100000,
    checkValve=true,
    redeclare function valveCharacteristic =
        Modelica.Fluid.Valves.BaseClasses.ValveCharacteristics.equalPercentage)
    annotation (Placement(transformation(extent={{152,514},{172,534}})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice E6(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.8) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-170,514})));
  Modelica.Fluid.Pipes.StaticPipe H7_R1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.195,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={83,524})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice K9(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={22,524})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice H12(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={62,524})));
  Modelica.Fluid.Pipes.StaticPipe s5(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=1.715) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={-15,524})));
  Modelica.Fluid.Pipes.StaticPipe K5_R1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.1,
    roughness=0) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={1,524})));
  Modelica.Fluid.Pipes.StaticPipe QS5(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    length=0.155,
    roughness=1e-5) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={43,524})));
  Modelica.Fluid.Pipes.StaticPipe K6_R1(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    height_ab=0,
    roughness=7e-6,
    length=0.5) annotation (Placement(transformation(
        extent={{-7,-10},{7,10}},
        rotation=0,
        origin={233,524})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice K10(
    redeclare package Medium = Medium,
    diameter=20e-3,
    use_zeta=true,
    zeta=0.4) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=0,
        origin={212,524})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice C5(
    redeclare package Medium = Medium,
    diameter=20e-3,
    zeta=1) annotation (Placement(transformation(extent={{244,514},{264,534}})));
  Modelica.Fluid.Sensors.Pressure pressure12(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{-10,10},{10,-10}},
        rotation=0,
        origin={194,484})));
  Modelica.Fluid.Sensors.Pressure pressure13(redeclare package Medium = Medium)
    annotation (Placement(transformation(extent={{184,446},{204,466}})));
  Modelica.Blocks.Math.Add add6(k1=1, k2=-1)
    annotation (Placement(transformation(extent={{220,458},{240,478}})));
  Modelica.Blocks.Interfaces.RealInput u_v_4
    annotation (Placement(transformation(extent={{-322,526},{-282,566}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_4_v
    annotation (Placement(transformation(extent={{400,484},{428,512}})));
  Modelica.Blocks.Interfaces.RealOutput y_v_4_p
    annotation (Placement(transformation(extent={{400,454},{428,482}})));
  Modelica.Fluid.Pipes.StaticPipe R20(
    redeclare package Medium = Medium,
    isCircular=true,
    diameter=20e-3,
    roughness=7e-6,
    length=3.3,
    height_ab=3.3) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-170,78})));
  Modelica.Fluid.Fittings.SimpleGenericOrifice E7(
    redeclare package Medium = Medium,
    use_zeta=true,
    diameter=20e-3,
    zeta=1.8) annotation (Placement(transformation(
        extent={{-10,-10},{10,10}},
        rotation=90,
        origin={-170,46})));
equation
  connect(SOURCE.ports[1], R1.port_a)
    annotation (Line(points={{330,-304},{318,-304}}, color={0,127,255}));
    P_ges =GF80_2.W_total + GF80_1.W_total;
    eta_ges =(GF80_2.dp_pump*GF80_2.V_flow + GF80_1.dp_pump*GF80_1.V_flow)/
    P_ges;
    head_ges =GF80_2.head + GF80_1.head;

  connect(T4S.port_b, R14.port_a)
    annotation (Line(points={{94,24},{94,68}}, color={0,127,255}));
  connect(R2.port_b, B2.port_a)
    annotation (Line(points={{278,-304},{270,-304}}, color={0,127,255}));
  connect(B2.port_b, R3.port_a)
    annotation (Line(points={{260,-304},{250,-304}}, color={0,127,255}));
  connect(R3.port_b, B3.port_a)
    annotation (Line(points={{234,-304},{230,-304}}, color={0,127,255}));
  connect(R4.port_a, B3.port_b)
    annotation (Line(points={{218,-310},{218,-304},{220,-304}},
                                                     color={0,127,255}));
  connect(R4.port_b, B4.port_a)
    annotation (Line(points={{218,-320},{218,-326}}, color={0,127,255}));
  connect(B4.port_b, R5.port_a)
    annotation (Line(points={{208,-326},{204,-326}},
                                                   color={0,127,255}));
  connect(T5S.port_b, R16.port_a)
    annotation (Line(points={{-74,24},{-74,66}}, color={0,127,255}));
  connect(E4.port_b, R17.port_a)
    annotation (Line(points={{-260,58},{-260,68}}, color={0,127,255}));
  connect(V2.port_b, D_H2.port_a)
    annotation (Line(points={{74,-204},{74,-200}},   color={0,127,255}));
  connect(R1.port_b, B1.port_a)
    annotation (Line(points={{310,-304},{304,-304}}, color={0,127,255}));
  connect(R2.port_a, B1.port_b)
    annotation (Line(points={{286,-304},{294,-304}}, color={0,127,255}));
  connect(D_H2.port_b, GF80_2.port_a)
    annotation (Line(points={{74,-188},{74,-184}},   color={0,127,255}));
  connect(V1.port_b, D_H1.port_a)
    annotation (Line(points={{150,-204},{150,-200}},
                                                   color={0,127,255}));
  connect(GF80_2.port_b, V4.port_a)
    annotation (Line(points={{74,-160},{74,-154}},   color={0,127,255}));
  connect(D_H1.port_b, GF80_1.port_a)
    annotation (Line(points={{150,-188},{150,-184}},
                                                   color={0,127,255}));
  connect(V3.port_a, GF80_1.port_b)
    annotation (Line(points={{150,-154},{150,-160}},
                                                   color={0,127,255}));
  connect(R5.port_b, Q_ges.port_a)
    annotation (Line(points={{190,-326},{186,-326}},
                                                   color={0,127,255}));
  connect(Q_ges.port_b, T1_1.port_a)
    annotation (Line(points={{156,-326},{150,-326}},
                                                   color={0,127,255}));
  connect(T1_1.port_b, H1.port_a)
    annotation (Line(points={{150,-316},{150,-302}},
                                                   color={0,127,255}));
  connect(V2.port_a, D_A2.port_b)
    annotation (Line(points={{74,-216},{74,-222}},   color={0,127,255}));
  connect(V1.port_a,D_A1. port_b)
    annotation (Line(points={{150,-216},{150,-222}}, color={0,127,255}));
  connect(R8.port_b, U2.port_a)
    annotation (Line(points={{74,-266},{74,-250}},   color={0,127,255}));
  connect(D_A2.port_a, U2.port_b)
    annotation (Line(points={{74,-234},{74,-240}},   color={0,127,255}));
  connect(R7.port_b, U1.port_a)
    annotation (Line(points={{150,-266},{150,-248}},
                                                   color={0,127,255}));
  connect(D_A1.port_a,U1. port_b)
    annotation (Line(points={{150,-234},{150,-238}}, color={0,127,255}));
  connect(D_B2.port_b, H4.port_a)
    annotation (Line(points={{74,-128},{74,-124}},   color={0,127,255}));
  connect(V4.port_b, D_B2.port_a)
    annotation (Line(points={{74,-142},{74,-138}},   color={0,127,255}));
  connect(D_B1.port_b, H3.port_a)
    annotation (Line(points={{150,-128},{150,-124}},
                                                   color={0,127,255}));
  connect(V3.port_b, D_B1.port_a)
    annotation (Line(points={{150,-142},{150,-138}},
                                                   color={0,127,255}));
  connect(H4.port_b, R10.port_a)
    annotation (Line(points={{74,-112},{74,-106}}, color={0,127,255}));
  connect(H3.port_b, R9.port_a)
    annotation (Line(points={{150,-112},{150,-106}},
                                                 color={0,127,255}));
  connect(H5_R.port_b,Q_floor1. port_a)
    annotation (Line(points={{216,140},{218,140}}, color={0,127,255}));
  connect(R16.port_b, E3.port_a)
    annotation (Line(points={{-74,86},{-72,86},{-72,382}},
                                                  color={0,127,255}));
  connect(Q_floor5.port_b,Valve_floor5. port_a)
    annotation (Line(points={{118,650},{156,650}}, color={0,127,255}));
  connect(Q_floor3.port_b,Valve_floor3. port_a)
    annotation (Line(points={{116,402},{156,402}}, color={0,127,255}));
  connect(Q_floor1.port_b,Valve_floor1. port_a)
    annotation (Line(points={{238,140},{260,140}}, color={0,127,255}));
  connect(H5_R.port_a,H5. port_b)
    annotation (Line(points={{202,140},{198,140}}, color={0,127,255}));
  connect(E2.port_b,s1. port_a)
    annotation (Line(points={{94,140},{106,140}},color={0,127,255}));
  connect(H5.port_a,QS1. port_b)
    annotation (Line(points={{178,140},{176,140}}, color={0,127,255}));
  connect(QS1.port_a,K1. port_b)
    annotation (Line(points={{162,140},{158,140}},
                                                 color={0,127,255}));
  connect(K1_R.port_b,K1. port_a)
    annotation (Line(points={{136,140},{138,140}},
                                                 color={0,127,255}));
  connect(K2_R.port_a,K2. port_b) annotation (Line(points={{312,140},{306,140}},
                                color={0,127,255}));
  connect(Valve_floor1.port_b,K2. port_a) annotation (Line(points={{280,140},{
          286,140}},                     color={0,127,255}));
  connect(H6_R.port_a, H6.port_b)
    annotation (Line(points={{78,402},{74,402}},   color={0,127,255}));
  connect(H6.port_a,QS2. port_b)
    annotation (Line(points={{54,402},{52,402}},   color={0,127,255}));
  connect(s2.port_b, K3_R.port_a)
    annotation (Line(points={{-6,402},{-4,402}}, color={0,127,255}));
  connect(QS2.port_a,K3. port_b)
    annotation (Line(points={{38,402},{34,402}}, color={0,127,255}));
  connect(K3_R.port_b, K3.port_a)
    annotation (Line(points={{10,402},{14,402}}, color={0,127,255}));
  connect(H7_R.port_a, H7.port_b)
    annotation (Line(points={{80,650},{76,650}},   color={0,127,255}));
  connect(H7.port_a, QS3.port_b)
    annotation (Line(points={{56,650},{54,650}},   color={0,127,255}));
  connect(s3.port_b, K5_R.port_a)
    annotation (Line(points={{-4,650},{-2,650}}, color={0,127,255}));
  connect(QS3.port_a,K5. port_b)
    annotation (Line(points={{40,650},{36,650}}, color={0,127,255}));
  connect(K5_R.port_b, K5.port_a)
    annotation (Line(points={{12,650},{16,650}}, color={0,127,255}));
  connect(E3.port_b, s2.port_a)
    annotation (Line(points={{-72,402},{-20,402}}, color={0,127,255}));
  connect(E5.port_b,s3. port_a)
    annotation (Line(points={{-260,650},{-18,650}},color={0,127,255}));
  connect(K4_R.port_a, K4.port_b)
    annotation (Line(points={{230,402},{226,402}}, color={0,127,255}));
  connect(K6_R.port_a, K6.port_b)
    annotation (Line(points={{230,650},{226,650}}, color={0,127,255}));
  connect(Valve_floor5.port_b, K6.port_a)
    annotation (Line(points={{176,650},{206,650}}, color={0,127,255}));
  connect(Valve_floor3.port_b,K4. port_a)
    annotation (Line(points={{176,402},{206,402}}, color={0,127,255}));
  connect(H6_R.port_b, Q_floor3.port_a)
    annotation (Line(points={{92,402},{96,402}},   color={0,127,255}));
  connect(H7_R.port_b, Q_floor5.port_a)
    annotation (Line(points={{94,650},{98,650}},   color={0,127,255}));
  connect(R9.port_b, T3_1.port_a)
    annotation (Line(points={{150,-86},{150,-82}},
                                                 color={0,127,255}));
  connect(T1_1.port_a, T1_2.port_a)
    annotation (Line(points={{150,-326},{134,-326}},
                                                   color={0,127,255}));
  connect(R6.port_a, T1_2.port_b)
    annotation (Line(points={{114,-326},{122,-326}},
                                                  color={0,127,255}));
  connect(R6.port_b, T2.port_a)
    annotation (Line(points={{94,-326},{74,-326}},   color={0,127,255}));
  connect(T2.port_b, H2.port_a)
    annotation (Line(points={{74,-316},{74,-300}},   color={0,127,255}));
  connect(R11.port_a, HB1.port_b) annotation (Line(points={{96,-77},{90,-77},{
          90,-78}},   color={0,127,255}));
  connect(R10.port_b, HB1.port_a)
    annotation (Line(points={{74,-86},{74,-78}},   color={0,127,255}));
  connect(R12.port_b, HB2.port_a)
    annotation (Line(points={{150,-44},{150,-40}},
                                                 color={0,127,255}));
  connect(HB2.port_b, R13.port_a)
    annotation (Line(points={{150,-24},{150,-14},{134,-14}},
                                                     color={0,127,255}));
  connect(R13.port_b, T4S.port_a)
    annotation (Line(points={{124,-14},{94,-14},{94,4}},
                                                     color={0,127,255}));
  connect(R13.port_b, T4D.port_a)
    annotation (Line(points={{124,-14},{82,-14}},
                                            color={0,127,255}));
  connect(U3.port_b, D_A3.port_a)
    annotation (Line(points={{-122,-14},{-124,-14}},
                                                 color={0,127,255}));
  connect(U3.port_a, T5D.port_b)
    annotation (Line(points={{-108,-14},{-102,-14}},
                                                 color={0,127,255}));
  connect(D_A3.port_b, V5.port_a)
    annotation (Line(points={{-136,-14},{-138,-14}},
                                                 color={0,127,255}));
  connect(V5.port_b, D_H3.port_a)
    annotation (Line(points={{-150,-14},{-152,-14}},
                                                 color={0,127,255}));
  connect(YONOS.port_a, D_H3.port_b)
    annotation (Line(points={{-166,-14},{-164,-14}},
                                                 color={0,127,255}));
  connect(H2.port_b, R8.port_a)
    annotation (Line(points={{74,-290},{74,-280}},   color={0,127,255}));
  connect(H1.port_b, R7.port_a)
    annotation (Line(points={{150,-292},{150,-280}},
                                                   color={0,127,255}));
  connect(D_B3.port_b, E4.port_a)
    annotation (Line(points={{-260,-14},{-260,38}},        color={0,127,255}));
  connect(V6.port_b, U4.port_a)
    annotation (Line(points={{-226,-14},{-232,-14}},
                                                 color={0,127,255}));
  connect(D_B3.port_a, U4.port_b)
    annotation (Line(points={{-248,-14},{-244,-14}},
                                                 color={0,127,255}));
  connect(K2_R.port_b, C1.port_a)
    annotation (Line(points={{326,140},{332,140}}, color={0,127,255}));
  connect(K4_R.port_b, C2.port_a)
    annotation (Line(points={{244,402},{248,402}}, color={0,127,255}));
  connect(K6_R.port_b, C3.port_a)
    annotation (Line(points={{244,650},{248,650}}, color={0,127,255}));
  connect(R11.port_b, T3_2.port_a)
    annotation (Line(points={{116,-77},{116,-76},{120,-76}},
                                                        color={0,127,255}));
  connect(T3_2.port_b, R12.port_a)
    annotation (Line(points={{140,-76},{140,-58},{150,-58}},
                                                          color={0,127,255}));
  connect(T3_1.port_b, R12.port_a)
    annotation (Line(points={{150,-66},{150,-58}},
                                                 color={0,127,255}));
  connect(Q_floor5.V_flow, y_v_5_v)
    annotation (Line(points={{108,639},{108,624},{414,624}}, color={0,0,127}));
  connect(Q_floor3.V_flow, y_v_3_v)
    annotation (Line(points={{106,391},{106,378},{414,378}}, color={0,0,127}));
  connect(Q_floor1.V_flow, y_v_1_v)
    annotation (Line(points={{228,129},{228,106},{414,106}}, color={0,0,127}));
  connect(GF80_1.port_b, pressure.port)
    annotation (Line(points={{150,-160},{178,-160}},
                                                   color={0,127,255}));
  connect(GF80_1.port_a, pressure1.port)
    annotation (Line(points={{150,-184},{178,-184}},
                                                   color={0,127,255}));
  connect(pressure.p, add.u1) annotation (Line(points={{189,-150},{194,-150},{
          194,-156},{202,-156}},
                            color={0,0,127}));
  connect(pressure1.p, add.u2) annotation (Line(points={{189,-174},{194,-174},{
          194,-168},{202,-168}},
                            color={0,0,127}));
  connect(add.y, y_p_1_p)
    annotation (Line(points={{225,-162},{416,-162}}, color={0,0,127}));
  connect(YONOS.port_b, pressure2.port)
    annotation (Line(points={{-186,-14},{-186,-33}},
                                                   color={0,127,255}));
  connect(YONOS.port_a, pressure3.port)
    annotation (Line(points={{-166,-14},{-166,-33}},
                                                   color={0,127,255}));
  connect(pressure2.p, add1.u2) annotation (Line(points={{-179,-40.7},{-179,
          -44.35},{-171.6,-44.35},{-171.6,-46.8}}, color={0,0,127}));
  connect(pressure3.p, add1.u1) annotation (Line(points={{-159,-40.7},{-159,
          -43.35},{-164.4,-43.35},{-164.4,-46.8}}, color={0,0,127}));
  connect(add1.y, y_p_2_p) annotation (Line(points={{-168,-60.6},{-168,-60},{
          300,-60},{300,-26},{414,-26}},
                     color={0,0,127}));
  connect(y_p_1_p, y_p_1_p)
    annotation (Line(points={{416,-162},{416,-162}}, color={0,0,127}));
  connect(H8.port_b, SINK1.ports[1]) annotation (Line(points={{-76,-74},{-92,
          -74},{-92,-121.333},{-102,-121.333}}, color={0,127,255}));
  connect(H9.port_b, SINK1.ports[2]) annotation (Line(points={{106,-130},{58,
          -130},{58,-124},{-102,-124}},  color={0,127,255}));
  connect(H10.port_b, SINK1.ports[3]) annotation (Line(points={{-156,-86},{-86,
          -86},{-86,-126.667},{-102,-126.667}}, color={0,127,255}));
  connect(H8.port_a, R10.port_b) annotation (Line(points={{-64,-74},{60,-74},{
          60,-86},{74,-86}},   color={0,127,255}));
  connect(H9.port_a, R9.port_b) annotation (Line(points={{118,-130},{134,-130},
          {134,-86},{150,-86}},
                             color={0,127,255}));
  connect(H10.port_a, D_B3.port_b) annotation (Line(points={{-168,-86},{-260,
          -86},{-260,-14}},
                          color={0,127,255}));
  connect(u_v_5, Valve_floor5.opening) annotation (Line(points={{-298,672},{166,
          672},{166,658}}, color={0,0,127}));
  connect(u_v_3, Valve_floor3.opening) annotation (Line(points={{-300,420},{166,
          420},{166,410}}, color={0,0,127}));
  connect(u_v_1, Valve_floor1.opening) annotation (Line(points={{-302,170},{270,
          170},{270,148}}, color={0,0,127}));
  connect(u_p_2, YONOS.N_in)
    annotation (Line(points={{-300,6},{-176,6},{-176,-4}},   color={0,0,127}));
  connect(u_p_1, GF80_2.N_in) annotation (Line(points={{-300,-166},{-254,-166},
          {-254,-172},{62,-172}},  color={0,0,127}));
  connect(u_p_1, GF80_1.N_in) annotation (Line(points={{-300,-166},{-254,-166},
          {-254,-160},{126,-160},{126,-172},{138,-172}},
                                                      color={0,0,127}));
  connect(s1.port_b, K1_R.port_a)
    annotation (Line(points={{120,140},{122,140}},
                                                 color={0,127,255}));
  connect(Q_ges.V_flow, y_p_1_v) annotation (Line(points={{171,-310.6},{273.5,
          -310.6},{273.5,-188},{414,-188}},color={0,0,127}));
  connect(pressure4.port, Valve_floor1.port_a) annotation (Line(points={{286,52},
          {248,52},{248,140},{260,140}}, color={0,127,255}));
  connect(pressure5.port, K2.port_a)
    annotation (Line(points={{286,98},{286,140}},          color={0,127,255}));
  connect(pressure5.p, add2.u2) annotation (Line(points={{297,88},{312,88},{312,
          80},{322,80}}, color={0,0,127}));
  connect(pressure4.p, add2.u1) annotation (Line(points={{297,62},{312,62},{312,
          68},{322,68}}, color={0,0,127}));
  connect(add2.y, y_v_1_p)
    annotation (Line(points={{345,74},{414,74}}, color={0,0,127}));
  connect(pressure8.port, K4.port_a) annotation (Line(points={{194,376},{182,
          376},{182,402},{206,402}}, color={0,127,255}));
  connect(pressure9.port, Valve_floor3.port_a) annotation (Line(points={{194,332},
          {142,332},{142,402},{156,402}},      color={0,127,255}));
  connect(pressure8.p, add4.u1) annotation (Line(points={{205,366},{211.5,366},
          {211.5,360},{218,360}}, color={0,0,127}));
  connect(pressure9.p, add4.u2) annotation (Line(points={{205,342},{212,342},{
          212,348},{218,348}}, color={0,0,127}));
  connect(add4.y, y_v_3_p)
    annotation (Line(points={{241,354},{414,354}}, color={0,0,127}));
  connect(pressure6.port, K6.port_a) annotation (Line(points={{198,620},{194,
          620},{194,650},{206,650}}, color={0,127,255}));
  connect(pressure7.port, Valve_floor5.port_a) annotation (Line(points={{198,572},
          {134,572},{134,650},{156,650}},      color={0,127,255}));
  connect(pressure7.p, add3.u2) annotation (Line(points={{209,582},{216,582},{
          216,588},{222,588}}, color={0,0,127}));
  connect(pressure6.p, add3.u1) annotation (Line(points={{209,610},{216,610},{
          216,600},{222,600}}, color={0,0,127}));
  connect(add3.y, y_v_5_p) annotation (Line(points={{245,594},{414,594}},
                           color={0,0,127}));
  connect(YONOS.port_b, Q_floor2.port_a)
    annotation (Line(points={{-186,-14},{-190,-14}}, color={0,127,255}));
  connect(V6.port_a, Q_floor2.port_b)
    annotation (Line(points={{-214,-14},{-210,-14}}, color={0,127,255}));
  connect(Q_floor2.V_flow, y_p_2_v) annotation (Line(points={{-200,-3},{156,-3},
          {156,-2},{414,-2}}, color={0,0,127}));
  connect(R17.port_b, E5.port_a)
    annotation (Line(points={{-260,88},{-260,630}}, color={0,127,255}));
  connect(R14.port_b, E2.port_a)
    annotation (Line(points={{94,88},{94,120}}, color={0,127,255}));
  connect(R15.port_a, T4D.port_b)
    annotation (Line(points={{56,-14},{66,-14}}, color={0,127,255}));
  connect(T5S.port_a, T5D.port_a)
    annotation (Line(points={{-74,4},{-74,-14},{-82,-14}}, color={0,127,255}));
  connect(R18.port_b, T5D.port_a)
    annotation (Line(points={{-54,-14},{-82,-14}}, color={0,127,255}));
  connect(R18.port_a, T4D1.port_b)
    annotation (Line(points={{-32,-14},{-22,-14}}, color={0,127,255}));
  connect(T4D1.port_a, R15.port_b)
    annotation (Line(points={{-6,-14},{34,-14}}, color={0,127,255}));
  connect(H5_R1.port_b, Q_floor4.port_a)
    annotation (Line(points={{216,276},{218,276}}, color={0,127,255}));
  connect(Q_floor4.port_b,Valve_floor2. port_a)
    annotation (Line(points={{238,276},{260,276}}, color={0,127,255}));
  connect(H5_R1.port_a, H11.port_b)
    annotation (Line(points={{202,276},{198,276}}, color={0,127,255}));
  connect(E1.port_b,s4. port_a)
    annotation (Line(points={{18,276},{106,276}},color={0,127,255}));
  connect(H11.port_a, QS4.port_b)
    annotation (Line(points={{178,276},{176,276}}, color={0,127,255}));
  connect(QS4.port_a,K7. port_b)
    annotation (Line(points={{162,276},{158,276}},
                                                 color={0,127,255}));
  connect(K1_R1.port_b, K7.port_a)
    annotation (Line(points={{136,276},{138,276}}, color={0,127,255}));
  connect(K2_R1.port_a, K8.port_b)
    annotation (Line(points={{312,276},{306,276}}, color={0,127,255}));
  connect(Valve_floor2.port_b,K8. port_a) annotation (Line(points={{280,276},{
          286,276}},                     color={0,127,255}));
  connect(K2_R1.port_b, C4.port_a)
    annotation (Line(points={{326,276},{332,276}}, color={0,127,255}));
  connect(Q_floor4.V_flow, y_v_2_v)
    annotation (Line(points={{228,265},{228,250},{414,250}}, color={0,0,127}));
  connect(u_v_2,Valve_floor2. opening) annotation (Line(points={{-302,306},{270,
          306},{270,284}}, color={0,0,127}));
  connect(s4.port_b, K1_R1.port_a)
    annotation (Line(points={{120,276},{122,276}}, color={0,127,255}));
  connect(pressure10.port, Valve_floor2.port_a) annotation (Line(points={{292,
          188},{248,188},{248,276},{260,276}}, color={0,127,255}));
  connect(pressure11.port, K8.port_a) annotation (Line(points={{292,238},{286,
          238},{286,276}}, color={0,127,255}));
  connect(pressure11.p, add5.u2) annotation (Line(points={{303,228},{312,228},{
          312,220},{326,220}}, color={0,0,127}));
  connect(pressure10.p, add5.u1) annotation (Line(points={{303,198},{312,198},{
          312,208},{326,208}}, color={0,0,127}));
  connect(add5.y, y_v_2_p)
    annotation (Line(points={{349,214},{414,214}}, color={0,0,127}));
  connect(R19.port_b, E1.port_a)
    annotation (Line(points={{18,86},{18,256}}, color={0,127,255}));
  connect(T4S1.port_a, R15.port_b) annotation (Line(points={{18,2},{16,2},{16,
          -14},{34,-14}}, color={0,127,255}));
  connect(R19.port_a, T4S1.port_b)
    annotation (Line(points={{18,66},{18,66},{18,22}}, color={0,127,255}));
  connect(Q_floor6.port_b,Valve_floor4. port_a)
    annotation (Line(points={{114,524},{152,524}}, color={0,127,255}));
  connect(H7_R1.port_a, H12.port_b)
    annotation (Line(points={{76,524},{72,524}}, color={0,127,255}));
  connect(H12.port_a, QS5.port_b)
    annotation (Line(points={{52,524},{50,524}}, color={0,127,255}));
  connect(s5.port_b, K5_R1.port_a)
    annotation (Line(points={{-8,524},{-6,524}}, color={0,127,255}));
  connect(QS5.port_a,K9. port_b)
    annotation (Line(points={{36,524},{32,524}}, color={0,127,255}));
  connect(K5_R1.port_b, K9.port_a)
    annotation (Line(points={{8,524},{12,524}}, color={0,127,255}));
  connect(E6.port_b,s5. port_a)
    annotation (Line(points={{-170,524},{-22,524}},color={0,127,255}));
  connect(K6_R1.port_a, K10.port_b)
    annotation (Line(points={{226,524},{222,524}}, color={0,127,255}));
  connect(Valve_floor4.port_b, K10.port_a)
    annotation (Line(points={{172,524},{202,524}}, color={0,127,255}));
  connect(H7_R1.port_b, Q_floor6.port_a)
    annotation (Line(points={{90,524},{94,524}}, color={0,127,255}));
  connect(K6_R1.port_b, C5.port_a)
    annotation (Line(points={{240,524},{244,524}}, color={0,127,255}));
  connect(Q_floor6.V_flow, y_v_4_v)
    annotation (Line(points={{104,513},{104,498},{414,498}}, color={0,0,127}));
  connect(u_v_4,Valve_floor4. opening) annotation (Line(points={{-302,546},{162,
          546},{162,532}}, color={0,0,127}));
  connect(pressure12.port, K10.port_a) annotation (Line(points={{194,494},{190,
          494},{190,524},{202,524}}, color={0,127,255}));
  connect(pressure13.port, Valve_floor4.port_a) annotation (Line(points={{194,
          446},{130,446},{130,524},{152,524}}, color={0,127,255}));
  connect(pressure13.p, add6.u2) annotation (Line(points={{205,456},{212,456},{
          212,462},{218,462}}, color={0,0,127}));
  connect(pressure12.p, add6.u1) annotation (Line(points={{205,484},{212,484},{
          212,474},{218,474}}, color={0,0,127}));
  connect(add6.y, y_v_4_p)
    annotation (Line(points={{241,468},{414,468}}, color={0,0,127}));
  connect(R20.port_b, E6.port_a)
    annotation (Line(points={{-170,88},{-170,504}}, color={0,127,255}));
  connect(E7.port_b, R20.port_a)
    annotation (Line(points={{-170,56},{-170,68}}, color={0,127,255}));
  connect(E7.port_a, U4.port_a) annotation (Line(points={{-170,36},{-232,36},{
          -232,-14}}, color={0,127,255}));
  connect(C1.port_b, SINK.ports[1]) annotation (Line(points={{352,140},{364,140},
          {364,322.8},{378,322.8}}, color={0,127,255}));
  connect(C4.port_b, SINK.ports[2]) annotation (Line(points={{352,276},{362,276},
          {362,324.4},{378,324.4}}, color={0,127,255}));
  connect(C2.port_b, SINK.ports[3]) annotation (Line(points={{268,402},{326,402},
          {326,326},{378,326}}, color={0,127,255}));
  connect(C5.port_b, SINK.ports[4]) annotation (Line(points={{264,524},{328,524},
          {328,327.6},{378,327.6}}, color={0,127,255}));
  connect(C3.port_b, SINK.ports[5]) annotation (Line(points={{268,650},{330,650},
          {330,329.2},{378,329.2}}, color={0,127,255}));
  connect(y_v_5_p, y_v_5_p)
    annotation (Line(points={{414,594},{414,594}}, color={0,0,127}));
  annotation (
    Icon(coordinateSystem(preserveAspectRatio=false, extent={{-280,-380},{400,
            700}})),
    Diagram(coordinateSystem(preserveAspectRatio=false, extent={{-280,-380},{
            400,700}})),
    uses(Modelica(version="3.2.3")));
end Hochhaus4;
